@@ -16,10 +16,15 @@ if(!defined("UPLOADED_ATTACHMENT_MAX_LIFETIME")) define("UPLOADED_ATTACHMENT_MAX
 if(!defined("ENABLE_PUBLIC_FOLDERS")) define("ENABLE_PUBLIC_FOLDERS", true);
 
 /**
- * Set to true to give users the option to enable conversation view in their settings
- * Set to false to hide the setting and disable conversation view for all users
+ * Set to true to give users the option to enable file previewer in their settings
+ * Set to false to hide the setting and disable file previewer for all users
  */
-if(!defined("ENABLE_CONVERSATION_VIEW")) define("ENABLE_CONVERSATION_VIEW", false);
+if(!defined("ENABLE_FILE_PREVIEWER")) define("ENABLE_FILE_PREVIEWER", true);
+
+/**
+ * Enable iconsets.
+ */
+if(!defined("ENABLE_ICONSETS")) define("ENABLE_ICONSETS", true);
 
 /**
  * Set to true to give users the possiblity to edit and create mail filters on the store
@@ -36,41 +41,35 @@ if(!defined("ENABLE_SHARED_RULES")) define("ENABLE_SHARED_RULES", false);
 if(!defined("ENABLE_RESPONSE_COMPRESSION")) define("ENABLE_RESPONSE_COMPRESSION", true);
 
 /**
- * When set to true this disables the fitlering of the HTML body.
+ * When set to false this disables the filtering of the HTML body.
  */
-if(!defined("DISABLE_HTMLBODY_FILTER")) define("DISABLE_HTMLBODY_FILTER", false);
+if(!defined("ENABLE_HTMLBODY_FILTER")) define("ENABLE_HTMLBODY_FILTER", true);
 
 /**
  * When set to true this enable the fitlering of the HTML body using DOMPurify.
  */
-if(!defined("ENABLE_DOMPURIFY_FILTER")) define("ENABLE_DOMPURIFY_FILTER", false);
+if(!defined("ENABLE_DOMPURIFY_FILTER")) define("ENABLE_DOMPURIFY_FILTER", true);
 
 /**
- * Set to true to load HTML filtered body's from kopano-server instead
- * of letting WebApp sanitize the HTML mail body.
+ * Set to false to enable login with Single Sign-On (SSO) on SSO environments.
  */
-if(!defined("KC_FILTERED_BODY")) define("KC_FILTERED_BODY", false);
+if(!defined("ENABLE_REMOTE_USER_LOGIN")) define("ENABLE_REMOTE_USER_LOGIN", true);
 
 /**
- * Set to true to disable login with Single Sign-On (SSO) on SSO environments.
+ * When set to false this disables the welcome screen shown to new users.
  */
-if(!defined("DISABLE_REMOTE_USER_LOGIN")) define("DISABLE_REMOTE_USER_LOGIN", false);
-
-/**
- * When set to true this disables the welcome screen to be shown for first time users.
- */
-if(!defined("DISABLE_WELCOME_SCREEN")) define("DISABLE_WELCOME_SCREEN", false);
+if(!defined("ENABLE_WELCOME_SCREEN")) define("ENABLE_WELCOME_SCREEN", true);
 
 /**
  * Set to true to disable the "What's new dialog" that will be shown to users to introduce new features.
  */
-if(!defined("DISABLE_WHATS_NEW_DIALOG")) define("DISABLE_WHATS_NEW_DIALOG", false);
+if(!defined("ENABLE_WHATS_NEW_DIALOG")) define("ENABLE_WHATS_NEW_DIALOG", true);
 
 /**
  * By default we won't disable the FULL GAB, as it is a performance option
  * which, when enabled, prevents the full GAB to be loaded'
  */
-if(!defined("DISABLE_FULL_GAB")) define("DISABLE_FULL_GAB", false);
+if(!defined("ENABLE_FULL_GAB")) define("ENABLE_FULL_GAB", true);
 
 /**
  * Set a maximum number of (search) results for the addressbook
@@ -80,16 +79,16 @@ if(!defined("DISABLE_FULL_GAB")) define("DISABLE_FULL_GAB", false);
 if(!defined("MAX_GAB_RESULTS")) define("MAX_GAB_RESULTS", 0);
 
 /**
- * By default we disable the public contact folders, as it is a performance option
- * which, when enabled, may cause delay in loading of address-book
+ * By default we disable the public contact folders,
+ * as it may increase address-book loading time.
  */
-if(!defined("DISABLE_PUBLIC_CONTACT_FOLDERS")) define("DISABLE_PUBLIC_CONTACT_FOLDERS", true);
+if(!defined("ENABLE_PUBLIC_CONTACT_FOLDERS")) define("ENABLE_PUBLIC_CONTACT_FOLDERS", false);
 
 /**
  * By default we disable the shared contact folders, as it is a performance option
  * which, when enabled, may cause delay in loading of address-book
  */
-if(!defined("DISABLE_SHARED_CONTACT_FOLDERS")) define("DISABLE_SHARED_CONTACT_FOLDERS", true);
+if(!defined("ENABLE_SHARED_CONTACT_FOLDERS")) define("ENABLE_SHARED_CONTACT_FOLDERS", false);
 
 /**
  * Limit the amount of members shown in the addressbook details dialog for a distlist. If the list
@@ -109,6 +108,11 @@ if(!defined("ENABLE_DIRECT_BOOKING")) define("ENABLE_DIRECT_BOOKING", true);
  */
 if(!defined("ENABLED_LANGUAGES")) define("ENABLED_LANGUAGES", "bg_BG;ca_ES;da_DK;el_GR;et_EE;fa_IR;gl_ES;hr_HR;ko_KR;lt_LT;pt_PT;si_SI;sv_SE;uk_UA;cs_CZ;de_DE;en_GB;en_US;es_ES;fr_FR;he_IL;it_IT;nl_NL;pt_BR;ru_RU;zh_CN;zh_TW;ja_JP;fi_FI;hu_HU;tr_TR;nb_NO;pl_PL");
 
+/**
+ * Defines the base URL where the User Manual for WebApp can be found
+ */
+if(!defined("PLUGIN_WEBAPPMANUAL_URL")) define("PLUGIN_WEBAPPMANUAL_URL", "https://documentation.kopano.io/user_manual_webapp/");
+
 /**
  * Defines the domains to which redirection after login is allowed. The redirect url will be read from
  * the GET-parameter 'continue'.
@@ -125,23 +129,27 @@ if(!defined("ENABLE_PLUGINS")) define("ENABLE_PLUGINS", true);
  */
 if(!defined("PATH_PLUGIN_CONFIG_DIR")) define("PATH_PLUGIN_CONFIG_DIR", PATH_PLUGIN_DIR);
 
+/**
+ * Enable widgets/today context.
+ */
+if(!defined("ENABLE_WIDGETS")) define("ENABLE_WIDGETS", true);
+
 /**
  * Defines a list of plugins that cannot be disabled by users.
  */
 if(!defined("ALWAYS_ENABLED_PLUGINS_LIST")) define("ALWAYS_ENABLED_PLUGINS_LIST", "");
 
+/**
+ * Enable themes.
+ */
+if(!defined("ENABLE_THEMES")) define("ENABLE_THEMES", true);
+
 /**
  * A theme. When this is not defined or empty or 'default', the default Kopano theme will be loaded.
  * The theme should the (directory)name of a installed theme plugin.
  */
 if(!defined("THEME")) define("THEME", "");
 
-/**
- * Set to true to give users the ability to chose a personal theme that will be shown
- * when they are logged in.
- */
-if(!defined("PERSONAL_THEMES_ENABLED")) define("PERSONAL_THEMES_ENABLED", false);
-
 /**
  * Use the classic icons as default iconset
  */
