@@ -33,6 +33,12 @@
 	header("Last-Modified: ".gmdate( "D, d M Y H:i:s")."GMT");
 	header("Cache-Control: no-cache, must-revalidate");
 	header("Pragma: no-cache");
+
+	// Add extra header for DeskApp to indicate that OIDC settings are configured.
+	if (OIDC_ISS !== "") {
+		header("X-Kopano-OIDCAuth:true");
+	}
+
 	if ( WebAppAuthentication::isAuthenticated() ) {
 		header("X-Zarafa: " . trim(file_get_contents(BASE_PATH . 'version')));
 	}
@@ -153,11 +159,11 @@
 	}
 
 	// Check if we can use gzip compression
-	if (ENABLE_RESPONSE_COMPRESSION && function_exists("gzencode") && isset($_SERVER["HTTP_ACCEPT_ENCODING"]) && strpos($_SERVER["HTTP_ACCEPT_ENCODING"], "gzip")!==false){
+	if (ENABLE_RESPONSE_COMPRESSION && function_exists("gzencode") && isset($_SERVER["HTTP_ACCEPT_ENCODING"]) && strpos($_SERVER["HTTP_ACCEPT_ENCODING"], "gzip")!==false) {
 		// Set the correct header and compress the response
 		header("Content-Encoding: gzip");
 		echo gzencode($json);
-	}else {
+	} else {
 		echo $json;
 	}
 
