@@ -57,6 +57,9 @@ class Backend extends \Files\Backend\Webdav\Backend implements iFeatureSharing
 		// set backend version
 		// TODO: this should be changed on every release
 		$this->backendVersion = "3.0";
+
+		// Backend name used in translations
+		$this->backendTransName = dgettext('plugin_filesbackendOwncloud', 'Files ownCloud Backend: ');
 	}
 
 	/**
@@ -160,7 +163,7 @@ class Backend extends \Files\Backend\Webdav\Backend implements iFeatureSharing
 		$serverHasCurl = function_exists('curl_version');
 		if (!$serverHasCurl) {
 			$e = new BackendException($this->parseErrorCodeToMessage(self::WD_ERR_NO_CURL), 500);
-			$e->setTitle(dgettext('plugin_filesbackendOwncloud', 'php-curl is not available'));
+			$e->setTitle($this->backendTransName . dgettext('plugin_filesbackendOwncloud', 'php-curl is not available'));
 			throw $e;
 		}
 
@@ -182,11 +185,11 @@ class Backend extends \Files\Backend\Webdav\Backend implements iFeatureSharing
 			$this->log('Failed to open: ' . $e->getMessage());
 			if (intval($e->getHTTPCode()) == 401) {
 				$e = new BackendException($this->parseErrorCodeToMessage(self::WD_ERR_UNAUTHORIZED), $e->getHTTPCode());
-				$e->setTitle(dgettext('plugin_filesbackendOwncloud', 'Files ownCloud Backend: Access denied'));
+				$e->setTitle($this->backendTransName . dgettext('plugin_filesbackendOwncloud', 'Access denied'));
 				throw $e;
 			} else {
 				$e = new BackendException($this->parseErrorCodeToMessage(self::WD_ERR_UNREACHABLE), $e->getHTTPCode());
-				$e->setTitle(dgettext('plugin_filesbackendOwncloud', 'Files ownCloud Backend: Connection failed'));
+				$e->setTitle($this->backendTransName . dgettext('plugin_filesbackendOwncloud', 'Connection failed'));
 				throw $e;
 			}
 		}
@@ -238,12 +241,12 @@ class Backend extends \Files\Backend\Webdav\Backend implements iFeatureSharing
 			return true;
 		} catch (ClientException $e) {
 			$e = new BackendException($this->parseErrorCodeToMessage($e->getCode()), $e->getCode());
-			$e->setTitle(dgettext('plugin_filesbackendOwncloud', 'Files ownCloud Backend: Sabre error'));
+			$e->setTitle($this->backendTransName . dgettext('plugin_filesbackendOwncloud', 'Sabre error'));
 			throw $e;
 		} catch (Exception $e) {
 			$this->log('[COPY] fatal: ' . $e->getMessage());
 			$e = new BackendException($this->parseErrorCodeToMessage($e->getHTTPCode()), $e->getHTTPCode());
-			$e->setTitle(dgettext('plugin_filesbackendOwncloud', 'Files ownCloud Backend: Copying failed'));
+			$e->setTitle($this->backendTransName . dgettext('plugin_filesbackendOwncloud', 'Copying failed'));
 			throw $e;
 		}
 	}
@@ -260,6 +263,7 @@ class Backend extends \Files\Backend\Webdav\Backend implements iFeatureSharing
 		$error = intval($error_code);
 
 		$msg = dgettext('plugin_filesbackendOwncloud', 'Unknown error');
+		$contactAdmin = dgettext('plugin_filesbackendOwncloud', 'Please contact your system administrator.');
 
 		switch ($error) {
 			case CURLE_BAD_PASSWORD_ENTERED:
@@ -286,20 +290,20 @@ class Backend extends \Files\Backend\Webdav\Backend implements iFeatureSharing
 				$msg = dgettext('plugin_filesbackendOwncloud', 'This file is locked by another user. Please try again later.');
 				break;
 			case self::WD_ERR_FAILED_DEPENDENCY:
-				$msg = dgettext('plugin_filesbackendOwncloud', 'The request failed due to failure of a previous request. Please contact your system administrator.');
+				$msg = dgettext('plugin_filesbackendOwncloud', 'The request failed.') . ' ' . $contactAdmin;
 				break;
 			case self::WD_ERR_INTERNAL:
 				// This is a general error, might be thrown due to a wrong IP, but we don't know.
-				$msg = dgettext('plugin_filesbackendOwncloud', 'The file server encountered an internal problem. Please contact your system administrator.');
+				$msg = dgettext('plugin_filesbackendOwncloud', 'The file server encountered an internal problem.') . ' ' . $contactAdmin;
 				break;
 			case self::WD_ERR_TMP:
-				$msg = dgettext('plugin_filesbackendOwncloud', 'We could not write to temporary directory. Please contact your system administrator.');
+				$msg = dgettext('plugin_filesbackendOwncloud', 'We could not write to temporary directory.') . ' ' . $contactAdmin;
 				break;
 			case self::WD_ERR_FEATURES:
-				$msg = dgettext('plugin_filesbackendOwncloud', 'We could not retrieve list of server features. Please contact the server administrator.');
+				$msg = dgettext('plugin_filesbackendOwncloud', 'We could not retrieve list of server features.') . ' ' . $contactAdmin;
 				break;
 			case self::WD_ERR_NO_CURL:
-				$msg = dgettext('plugin_filesbackendOwncloud', 'PHP-Curl is not available. Please contact your system administrator.');
+				$msg = dgettext('plugin_filesbackendOwncloud', 'PHP-Curl is not available.') . ' ' . $contactAdmin;
 				break;
 		}
 
