@@ -108,20 +108,23 @@ class Backend extends AbstractBackend implements iFeatureQuota, iFeatureVersionI
 	function __construct()
 	{
 
-		// initialization
+		// Initialization
 		$this->debug = PLUGIN_FILESBROWSER_LOGLEVEL === "DEBUG" ? true : false;
 
 		$this->init_form();
 
-		// set backend description
+		// Set backend description
 		$this->backendDescription = dgettext('plugin_filesbackendSMB', "With this backend, you can connect to any samba server (e.g. Windows Share).");
 		
-		// set backend display name
+		// Set backend display name
 		$this->backendDisplayName = "SMB";
 
-		// set backend version
+		// Set backend version
 		// TODO: this should be changed on every release
 		$this->backendVersion = "3.0";
+		
+		// Backend name used in translations	
+		$this->backendTransName = dgettext('plugin_filesbackendSMB', 'Files SMB Backend: ');
 	}
 
 	/**
@@ -346,33 +349,33 @@ class Backend extends AbstractBackend implements iFeatureQuota, iFeatureVersionI
 		} catch (AccessDeniedException $e) {
 			$this->log("AccessDeniedException: " . print_r($e, true));
 			$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_UNAUTHORIZED), self::SMB_ERR_UNAUTHORIZED);
-			$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Access denied'));
+			$e->setTitle($this->backendTransName . dgettext('plugin_filesbackendSMB', 'Access denied'));
 			throw $e;
 		} catch (ForbiddenException $e) {
 			$this->log("ForbiddenException: " . print_r($e, true));
 			$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_FORBIDDEN), self::SMB_ERR_FORBIDDEN);
-			$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Forbidden'));
+			$e->setTitle($this->backendTransName . dgettext('plugin_filesbackendSMB', 'Forbidden'));
 			throw $e;
 		} catch (AuthenticationException $e) {
 			$this->log("AuthenticationException: " . print_r($e, true));
 			$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_UNAUTHORIZED), self::SMB_ERR_UNAUTHORIZED);
-			$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Authentication failed'));
+			$e->setTitle($this->backendTransName . dgettext('plugin_filesbackendSMB', 'Authentication failed'));
 			throw $e;
 		} catch (TimedOutException $e) {
 			$this->log("TimedOutException: " . print_r($e, true));
 			$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_UNREACHABLE), self::SMB_ERR_UNREACHABLE);
-			$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Timeout'));
+			$e->setTitle($this->backendTransName . dgettext('plugin_filesbackendSMB', 'Timeout'));
 			throw $e;
 		} catch (ConnectionRefusedException $e) {
 			$this->log("ConnectionRefusedException " . print_r($e, true));
 			$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_UNREACHABLE), self::SMB_ERR_UNREACHABLE);
-			$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Connection refused'));
+			$e->setTitle($this->backendTransName . dgettext('plugin_filesbackendSMB', 'Connection refused'));
 			throw $e;
 		} catch (\Exception $e) {
 			// Something else failed...
 			$this->log("General exception, opening failed: " . print_r($e, true));
 			$e = new BackendException($e->getMessage(), self::SMB_ERR_INTERNAL);
-			$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Connection failed'));
+			$e->setTitle($this->backendTransName . dgettext('plugin_filesbackendSMB', 'Connection failed'));
 			throw $e;
 		}
 
@@ -401,22 +404,22 @@ class Backend extends AbstractBackend implements iFeatureQuota, iFeatureVersionI
 		} catch (ForbiddenException $e) {
 			$this->log("LS ForbiddenException: " . print_r($e, true));
 			$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_FORBIDDEN), self::SMB_ERR_FORBIDDEN);
-			$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Forbidden'));
+			$e->setTitle($this->backendTransName . dgettext('plugin_filesbackendSMB', 'Forbidden'));
 			throw $e;
 		} catch (NotFoundException $e) {
 			$this->log("LS NotFoundException: " . print_r($e, true));
 			$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_NOTFOUND), self::SMB_ERR_NOTFOUND);
-			$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Not found'));
+			$e->setTitle($this->backendTransName . dgettext('plugin_filesbackendSMB', 'Not found'));
 			throw $e;
 		} catch (InvalidTypeException $e) {
 			$this->log("LS InvalidTypeException: " . print_r($e, true));
 			$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_INV_TYPE), self::SMB_ERR_INV_TYPE);
-			$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Invalid item type'));
+			$e->setTitle($this->backendTransName . dgettext('plugin_filesbackendSMB', 'Invalid item type'));
 			throw $e;
 		} catch (\Exception $e) {
 			$this->log("LS General exception thrown, failed: " . print_r($e, true));
 			$e = new BackendException($e->getMessage(), self::SMB_ERR_NOTFOUND);
-			$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Failed to list items'));
+			$e->setTitle($this->backendTransName . dgettext('plugin_filesbackendSMB', 'Failed to list items'));
 			throw $e;
 		}
 
@@ -456,28 +459,28 @@ class Backend extends AbstractBackend implements iFeatureQuota, iFeatureVersionI
 	 */
 	public function mkcol($dir)
 	{
-		$this->log("creating dir: " . $dir);
+		$this->log("Creating dir: " . $dir);
 		try {
 			$this->smb_share->mkdir($dir);
 		} catch (NotFoundException $e) {
 			$this->log("MKCOL NotFoundException: " . print_r($e, true));
 			$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_NOTFOUND), self::SMB_ERR_NOTFOUND);
-			$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Directory not found'));
+			$e->setTitle($this->backendTransName . dgettext('plugin_filesbackendSMB', 'Directory not found'));
 			throw $e;
 		} catch (AlreadyExistsException $e) {
 			$this->log("MKCOL AlreadyExistsException: " . print_r($e, true));
 			$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_ALREADY_EXISTS), self::SMB_ERR_ALREADY_EXISTS);
-			$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Directory already exist'));
+			$e->setTitle($this->backendTransName . dgettext('plugin_filesbackendSMB', 'Directory already exist'));
 			throw $e;
 		} catch (ForbiddenException $e) {
 			$this->log("MKCOL ForbiddenException: " . print_r($e, true));
 			$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_FORBIDDEN), self::SMB_ERR_FORBIDDEN);
-			$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Forbidden'));
+			$e->setTitle($this->backendTransName . dgettext('plugin_filesbackendSMB', 'Forbidden'));
 			throw $e;
 		} catch (\Exception $e) {
 			$this->log("MKCOL general exception: " . print_r($e, true));
 			$e = new BackendException($e->getMessage(), self::SMB_ERR_INTERNAL);
-			$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Failed'));
+			$e->setTitle($this->backendTransName . dgettext('plugin_filesbackendSMB', 'Failed'));
 			throw $e;
 		}
 
@@ -514,22 +517,22 @@ class Backend extends AbstractBackend implements iFeatureQuota, iFeatureVersionI
 			} catch (NotFoundException $e) {
 				$this->log("Remove directory NotFoundException: " . print_r($e, true));
 				$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_NOTFOUND), self::SMB_ERR_NOTFOUND);
-				$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Directory not found'));
+				$e->setTitle($this->backendTransName . dgettext('plugin_filesbackendSMB', 'Directory not found'));
 				throw $e;
 			} catch (InvalidTypeException $e) {
 				$this->log("Remove directory InvalidTypeException: " . print_r($e, true));
 				$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_INV_TYPE), self::SMB_ERR_INV_TYPE);
-				$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Invalid Type'));
+				$e->setTitle($this->backendTransName . dgettext('plugin_filesbackendSMB', 'Invalid Type'));
 				throw $e;
 			} catch (ForbiddenException $e) {
 				$this->log("Remove directory ForbiddenException: " . print_r($e, true));
 				$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_FORBIDDEN), self::SMB_ERR_FORBIDDEN);
-				$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Forbidden'));
+				$e->setTitle($this->backendTransName . dgettext('plugin_filesbackendSMB', 'Forbidden'));
 				throw $e;
 			} catch (\Exception $e) {
 				$this->log("Remove directory general exception: " . print_r($e, true));
 				$e = new BackendException($e->getMessage(), self::SMB_ERR_INTERNAL);
-				$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Deletion failed'));
+				$e->setTitle($this->backendTransName . dgettext('plugin_filesbackendSMB', 'Deletion failed'));
 				throw $e;
 			}
 		} else {
@@ -538,22 +541,22 @@ class Backend extends AbstractBackend implements iFeatureQuota, iFeatureVersionI
 			} catch (NotFoundException $e) {
 				$this->log("Remove file NotFoundException: " . print_r($e, true));
 				$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_NOTFOUND), self::SMB_ERR_NOTFOUND);
-				$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Not found'));
+				$e->setTitle($this->backendTransName . dgettext('plugin_filesbackendSMB', 'Not found'));
 				throw $e;
 			} catch (InvalidTypeException $e) {
 				$this->log("Remove file InvalidTypeException: " . print_r($e, true));
 				$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_INV_TYPE), self::SMB_ERR_INV_TYPE);
-				$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Invalid type'));
+				$e->setTitle($this->backendTransName . dgettext('plugin_filesbackendSMB', 'Invalid type'));
 				throw $e;
 			} catch (ForbiddenException $e) {
 				$this->log("Remove file ForbiddenException: " . print_r($e, true));
 				$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_FORBIDDEN), self::SMB_ERR_FORBIDDEN);
-				$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Forbidden'));
+				$e->setTitle($this->backendTransName . dgettext('plugin_filesbackendSMB', 'Forbidden'));
 				throw $e;
 			} catch (\Exception $e) {
 				$this->log("Remove file general exception, failed: " . print_r($e, true));
 				$e = new BackendException($e->getMessage(), self::SMB_ERR_INTERNAL);
-				$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Deletion failed'));
+				$e->setTitle($this->backendTransName . dgettext('plugin_filesbackendSMB', 'Deletion failed'));
 				throw $e;
 			}
 		}
@@ -605,22 +608,22 @@ class Backend extends AbstractBackend implements iFeatureQuota, iFeatureVersionI
 		} catch (NotFoundException $e) {
 			$this->log("Move NotFoundException: " . print_r($e, true));
 			$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_NOTFOUND), self::SMB_ERR_NOTFOUND);
-			$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Not found'));
+			$e->setTitle($this->backendTransName . dgettext('plugin_filesbackendSMB', 'Not found'));
 			throw $e;
 		} catch (AlreadyExistsException $e) {
 			$this->log("Move AlreadyExistsException: " . print_r($e, true));
 			$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_ALREADY_EXISTS), self::SMB_ERR_ALREADY_EXISTS);
-			$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Already exist'));
+			$e->setTitle($this->backendTransName . dgettext('plugin_filesbackendSMB', 'Already exist'));
 			throw $e;
 		} catch (ForbiddenException $e) {
 			$this->log("Move ForbiddenException: " . print_r($e, true));
 			$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_FORBIDDEN), self::SMB_ERR_FORBIDDEN);
-			$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Forbidden'));
+			$e->setTitle($this->backendTransName . dgettext('plugin_filesbackendSMB', 'Forbidden'));
 			throw $e;
 		} catch (\Exception $e) {
 			$this->log("Move general exception, failed: " . print_r($e, true));
 			$e = new BackendException($e->getMessage(), self::SMB_ERR_INTERNAL);
-			$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Moving failed'));
+			$e->setTitle($this->backendTransName . dgettext('plugin_filesbackendSMB', 'Moving failed'));
 			throw $e;
 		}
 
@@ -647,7 +650,7 @@ class Backend extends AbstractBackend implements iFeatureQuota, iFeatureVersionI
 			return $result;
 		} else {
 			$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_TMP), self::SMB_ERR_TMP);
-			$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Issues with TMP directory'));
+			$e->setTitle($this->backendTransName . dgettext('plugin_filesbackendSMB', 'Issues with TMP directory'));
 			throw $e;
 		}
 	}
@@ -670,22 +673,22 @@ class Backend extends AbstractBackend implements iFeatureQuota, iFeatureVersionI
 		} catch (NotFoundException $e) {
 			$this->log("put_file NotFoundException: " . print_r($e, true));
 			$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_NOTFOUND), self::SMB_ERR_NOTFOUND);
-			$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Not found'));
+			$e->setTitle($this->backendTransName . dgettext('plugin_filesbackendSMB', 'Not found'));
 			throw $e;
 		} catch (InvalidTypeException $e) {
 			$this->log("put_file InvalidTypeException: " . print_r($e, true));
 			$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_INV_TYPE), self::SMB_ERR_INV_TYPE);
-			$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Invalid type'));
+			$e->setTitle($this->backendTransName . dgettext('plugin_filesbackendSMB', 'Invalid type'));
 			throw $e;
 		} catch (ForbiddenException $e) {
 			$this->log("put_file ForbiddenException: " . print_r($e, true));
 			$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_FORBIDDEN), self::SMB_ERR_FORBIDDEN);
-			$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Forbidden'));
+			$e->setTitle($this->backendTransName . dgettext('plugin_filesbackendSMB', 'Forbidden'));
 			throw $e;
 		} catch (\Exception $e) {
 			$this->log("put_file general exception, failed: " . print_r($e, true));
 			$e = new BackendException($e->getMessage(), self::SMB_ERR_INTERNAL);
-			$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Uploading failed'));
+			$e->setTitle($this->backendTransName . dgettext('plugin_filesbackendSMB', 'Uploading failed'));
 			throw $e;
 		}
 
@@ -714,7 +717,7 @@ class Backend extends AbstractBackend implements iFeatureQuota, iFeatureVersionI
 				return $result;
 			} else {
 				$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_TMP), self::SMB_ERR_TMP);
-				$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Issues with TMP directory'));
+				$e->setTitle($this->backendTransName . dgettext('plugin_filesbackendSMB', 'Issues with TMP directory'));
 				throw $e;
 			}
 		} else {
@@ -740,17 +743,17 @@ class Backend extends AbstractBackend implements iFeatureQuota, iFeatureVersionI
 		} catch (NotFoundException $e) {
 			$this->log("get_file NotFoundException: " . print_r($e, true));
 			$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_NOTFOUND), self::SMB_ERR_NOTFOUND);
-			$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Not found'));
+			$e->setTitle($this->backendTransName . dgettext('plugin_filesbackendSMB', 'Not found'));
 			throw $e;
 		} catch (InvalidTypeException $e) {
 			$this->log("get_file InvalidTypeException: " . print_r($e, true));
 			$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_INV_TYPE), self::SMB_ERR_INV_TYPE);
-			$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Invalid type'));
+			$e->setTitle($this->backendTransName . dgettext('plugin_filesbackendSMB', 'Invalid type'));
 			throw $e;
 		} catch (\Exception $e) {
 			$this->log("get_file general exception, failed: " . print_r($e, true));
 			$e = new BackendException($e->getMessage(), self::SMB_ERR_INTERNAL);
-			$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Failed to get file'));
+			$e->setTitle($this->backendTransName . dgettext('plugin_filesbackendSMB', 'Failed to get file'));
 			throw $e;
 		}
 
@@ -777,7 +780,7 @@ class Backend extends AbstractBackend implements iFeatureQuota, iFeatureVersionI
 	{
 		// TODO Fix or remove me
 		$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_UNIMPLEMENTED), self::SMB_ERR_UNIMPLEMENTED);
-		$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Not implemented'));
+		$e->setTitle($this->backendTransName . dgettext('plugin_filesbackendSMB', 'Not implemented'));
 		throw $e;
 	}
 
@@ -801,7 +804,7 @@ class Backend extends AbstractBackend implements iFeatureQuota, iFeatureVersionI
 	{
 		// TODO Fix or remove me
 		$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_UNIMPLEMENTED), self::SMB_ERR_UNIMPLEMENTED);
-		$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Not implemented'));
+		$e->setTitle($this->backendTransName . dgettext('plugin_filesbackendSMB', 'Not implemented'));
 		throw $e;
 	}
 
@@ -825,7 +828,7 @@ class Backend extends AbstractBackend implements iFeatureQuota, iFeatureVersionI
 
 		$this->log('gpi: wrong response from ls');
 		$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_FAILED_DEPENDENCY), self::SMB_ERR_FAILED_DEPENDENCY);
-		$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Request failed'));
+		$e->setTitle($this->backendTransName . dgettext('plugin_filesbackendSMB', 'Request failed'));
 		throw $e;
 	}
 
@@ -839,7 +842,7 @@ class Backend extends AbstractBackend implements iFeatureQuota, iFeatureVersionI
 	{
 		// TODO Fix or remove me
 		$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_UNIMPLEMENTED), self::SMB_ERR_UNIMPLEMENTED);
-		$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Not implemented'));
+		$e->setTitle($this->backendTransName . dgettext('plugin_filesbackendSMB', 'Not implemented'));
 		throw $e;
 	}
 
@@ -923,7 +926,7 @@ class Backend extends AbstractBackend implements iFeatureQuota, iFeatureVersionI
 	{
 		// TODO Fix or remove me
 		$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_UNIMPLEMENTED), self::SMB_ERR_UNIMPLEMENTED);
-		$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Not implemented'));
+		$e->setTitle($this->backendTransName . dgettext('plugin_filesbackendSMB', 'Not implemented'));
 		throw $e;
 	}
 
@@ -938,6 +941,7 @@ class Backend extends AbstractBackend implements iFeatureQuota, iFeatureVersionI
 	{
 		$error = intval($error_code);
 		$msg = dgettext('plugin_filesbackendSMB', 'Unknown error');
+		$contactAdmin = dgettext('plugin_filesbackendSMB', 'Please contact your system administrator.');
 
 		switch ($error) {
 			case self::SMB_ERR_UNAUTHORIZED:
@@ -956,20 +960,20 @@ class Backend extends AbstractBackend implements iFeatureQuota, iFeatureVersionI
 				$msg = dgettext('plugin_filesbackendSMB', 'Connection to the file server timed out. Please check again later.');
 				break;
 			case self::SMB_ERR_FAILED_DEPENDENCY:
-				$msg = dgettext('plugin_filesbackendSMB', 'The request failed due to failure of a previous request. Please contact your system administrator.');
+				$msg = dgettext('plugin_filesbackendSMB', 'The request failed.') . ' ' . $contactAdmin;
 				break;
 			case self::SMB_ERR_INTERNAL:
 				// This is a general error, might be thrown due to a wrong IP, but we don't know.
-				$msg = dgettext('plugin_filesbackendSMB', 'The file server encountered an internal problem. Please contact your system administrator');
+				$msg = dgettext('plugin_filesbackendSMB', 'The file server encountered an internal problem.') . ' ' . $contactAdmin;
 				break;
 			case self::SMB_ERR_TMP:
-				$msg = dgettext('plugin_filesbackendSMB', 'We could not write to temporary directory. Please contact your system administrator.');
+				$msg = dgettext('plugin_filesbackendSMB', 'We could not write to temporary directory.') . ' ' . $contactAdmin;
 				break;
 			case self::SMB_ERR_FEATURES:
-				$msg = dgettext('plugin_filesbackendSMB', 'We could not retrieve list of server features. Please contact the server administrator.');
+				$msg = dgettext('plugin_filesbackendSMB', 'We could not retrieve list of server features.') . ' ' . $contactAdmin;
 				break;
 			case self::SMB_ERR_NO_SMB_LIB:
-				$msg = dgettext('plugin_filesbackendSMB', 'libsmbclient-php is not available. Please contact your system administrator.');
+				$msg = dgettext('plugin_filesbackendSMB', 'libsmbclient-php is not available.') . ' ' . $contactAdmin;
 				break;
 			case self::SMB_ERR_INV_TYPE:
 				$msg = dgettext('plugin_filesbackendSMB', 'Destination is not valid. Please select a valid folder.');
