@@ -8,6 +8,18 @@
 	 */
 	class filter
 	{
+
+		/**
+		 * A boolean value set true to Filter html content forcefully default is false.
+		 * @var bool
+		 */
+		private $forceFilterHTML;
+
+		function __construct($forceFilterHTML = false)
+		{
+			$this->forceFilterHTML = $forceFilterHTML;
+		}	
+
 		/**
 		 * Create script-safe HTML from raw HTML
 		 *
@@ -19,7 +31,7 @@
 			// Save all "<" symbols
 			$html = preg_replace("/<(?=[^a-zA-Z\/\!\?\%])/", "&lt;", $html);
 
-			if(!DISABLE_HTMLBODY_FILTER && !ENABLE_DOMPURIFY_FILTER){
+			if(ENABLE_HTMLBODY_FILTER && (!ENABLE_DOMPURIFY_FILTER || $this->forceFilterHTML)) {
 				// Filter '<script>'
 				$html = magicHTML($html);
 			}
