@@ -29,7 +29,7 @@
 		/**
 		 * @var string The entryid (binary) of the default store
 		 */
-		private $defaultstore;
+		private $defaultStore;
 
 		/**
 		 * @var string The entryid (binary) of the public store
@@ -59,8 +59,8 @@
 		function __construct()
 		{
 			$this->stores = array();
-			$this->defaultstore = 0;
-			$this->publicStore = 0;
+			$this->defaultStore = null;
+			$this->publicStore = null;
 			$this->session = false;
 			$this->ab = false;
 			$this->userstores = array();
@@ -90,7 +90,7 @@
 			$flags |= 1; // Always disable notifications
 
 			try {
-				$webapp_version = 'WebApp-'.trim(file_get_contents(BASE_PATH . 'version'));
+				$webapp_version = 'WebApp-'.getWebappVersion();
 				$browser_version = isset($_SERVER['HTTP_USER_AGENT']) ? $_SERVER['HTTP_USER_AGENT'] : '';
 				$this->session = mapi_logon_zarafa($username, $password, $server, $sslcert_file,
 								   $sslcert_pass, $flags, $webapp_version, $browser_version);
@@ -146,8 +146,7 @@
 				$user = $this->getUser($store_props[PR_USER_ENTRYID]);
 
 				// receive userdata
-				// TODO: 0x8C9E0102 represents an LDAP jpegPhoto and should get a named property PR_EMS_AB_THUMBNAIL_PHOTO
-				$user_props = array(PR_DISPLAY_NAME, PR_SMTP_ADDRESS, PR_EMAIL_ADDRESS, PR_SEARCH_KEY, 0x8C9E0102, PR_ASSISTANT_TELEPHONE_NUMBER);
+				$user_props = array(PR_DISPLAY_NAME, PR_SMTP_ADDRESS, PR_EMAIL_ADDRESS, PR_SEARCH_KEY, PR_EMS_AB_THUMBNAIL_PHOTO, PR_ASSISTANT_TELEPHONE_NUMBER);
 				$properties = new properties();
 				$user_props = array_merge($user_props, $properties->getAddressBookItemMailuserProperties());
 
@@ -159,7 +158,7 @@
 					$this->session_info["smtpaddress"] = $user_props[PR_SMTP_ADDRESS];
 					$this->session_info["emailaddress"] = $user_props[PR_EMAIL_ADDRESS];
 					$this->session_info["searchkey"] = $user_props[PR_SEARCH_KEY];
-					$this->session_info["userimage"] = isset($user_props[-1935802110]) ? base64_encode($user_props[-1935802110]) : "";
+					$this->session_info["userimage"] = isset($user_props[PR_EMS_AB_THUMBNAIL_PHOTO]) ? base64_encode($user_props[PR_EMS_AB_THUMBNAIL_PHOTO]) : "";
 					$this->session_info["userimage"] = strlen($this->session_info["userimage"]) > 0 ? "data:image/png;base64," . $this->session_info["userimage"] : "" ;
 
 					$this->session_info["given_name"] = isset($user_props[PR_GIVEN_NAME]) ? $user_props[PR_GIVEN_NAME] : '';
@@ -301,7 +300,7 @@
 		function getUserName()
 		{
 			$encryptionStore = EncryptionStore::getInstance();
-			return $encryptionStore->get('username') ? $encryptionStore->get('username'): '';
+			return $encryptionStore->get('username') ? $encryptionStore->get('username') : '';
 		}
 
 		/**
@@ -345,7 +344,7 @@
 		{
 			$this->retrieveUserData();
 
-			return array_key_exists("userimage",$this->session_info)? $this->session_info["userimage"]:false;
+			return array_key_exists("userimage",$this->session_info)? $this->session_info["userimage"] : false;
 		}
 
 		/**
@@ -380,15 +379,19 @@
 		 public function __call($methodName, $arguments)
 		 {
 		 	if ( !preg_match('/^get(.+)$/', $methodName, $matches) ){
-		 		// We don't know this function, so let's throw an error
-		 		throw new Exception('Method ' . $methodName . ' does not exist');
-		 	}else{
+				// This function is unknown. log the error and return an empty string as a value.
+				error_log('Method ' . $methodName . ' does not exist');
+				Log::Write(LOGLEVEL_ERROR, 'Method ' . $methodName . ' does not exist');
+				return "";
+		 	} else {
 		 		$this->retrieveUserData();
 		 		$propertyName = strtolower(preg_replace('/([^A-Z])([A-Z])/', '$1_$2', $matches[1]));
 				if ( !array_key_exists($propertyName, $this->session_info) ){
-			 		// We don't know this function, so let's throw an error
-			 		throw new Exception('Method ' . $methodName . ' does not exist '.$propertyName);
-				}else{
+					// This function is unknown. log the error and return an empty string as a value.
+					error_log('Method ' . $methodName . ' does not exist '.$propertyName);
+					Log::Write(LOGLEVEL_ERROR, 'Method ' . $methodName . ' does not exist '.$propertyName);
+					return "";
+				} else {
 					return $this->session_info[$propertyName];
 				}
 		 	}
@@ -475,8 +478,8 @@
 		function getDefaultMessageStore($reopen = False)
 		{
 			// Return cached default store if we have one
-			if (!$reopen && isset($this->defaultstore) && isset($this->stores[$this->defaultstore])) {
-				return $this->stores[$this->defaultstore];
+			if (!$reopen && isset($this->defaultStore) && isset($this->stores[$this->defaultStore])) {
+				return $this->stores[$this->defaultStore];
 			}
 
 			$this->loadMessageStoresFromSession();
@@ -539,6 +542,9 @@
 			}
 
 			$this->loadMessageStoresFromSession();
+			if(!isset($this->publicStore)) {
+				return false;
+			}
 			return $this->openMessageStore($this->publicStore, 'Public store');
 		}
 
@@ -583,13 +589,13 @@
 				// Cache the store for later use
 				$this->stores[$entryid] = $store;
 			} catch (MAPIException $e) {
-				error_log('Failed to open store with entryid ' . $entryid . ($name ? " ($name)":''));
+				error_log('Failed to open store with entryid ' . bin2hex($entryid) . ($name ? " ($name)" : ''));
 				error_log($e);
 				return $e->getCode();
 			} catch (Exception $e ) {
 				// mapi_openmsgstore seems to throw another exception than MAPIException
 				// sometimes, so we add a safety net.
-				error_log('Failed to open store with entryid ' . $entryid . ($name ? " ($name)":''));
+				error_log('Failed to open store with entryid ' . bin2hex($entryid) . ($name ? " ($name)" : ''));
 				error_log($e);
 				return $e->getCode();
 			}
@@ -661,6 +667,8 @@
 		function getOtherUserStore()
 		{
 			$otherusers = $this->retrieveOtherUsersFromSettings();
+			$otheUsersStores = Array();
+
 			foreach($otherusers as $username=>$folder) {
 				if (isset($this->userstores[$username])) {
 					continue;
@@ -670,7 +678,11 @@
 					try {
 						$user_entryid = mapi_msgstore_createentryid($this->getDefaultMessageStore(), $username);
 
-						$this->openMessageStore($user_entryid, $username);
+						$sharedStore =  $this->openMessageStore($user_entryid, $username);
+						if($sharedStore !== false) {
+							array_push($otheUsersStores ,$sharedStore);
+						}
+
 						$this->userstores[$username] = $user_entryid;
 
 						// Check if an entire store will be loaded, if so load the archive store as well
@@ -692,6 +704,7 @@
 					}
 				}
 			}
+			return $otheUsersStores;
 		}
 
 		/**
@@ -871,8 +884,8 @@
 				$defaultStore = $this->getDefaultMessageStore();
 				$contactFolders = $this->getContactFoldersForABContactProvider($defaultStore);
 
-				// include shared contact folders in addressbook if shared contact folders are not disabled
-				if (!DISABLE_SHARED_CONTACT_FOLDERS && $loadSharedContactsProvider) {
+				// include shared contact folders in addressbook if shared contact folders are enabled
+				if (ENABLE_SHARED_CONTACT_FOLDERS && $loadSharedContactsProvider) {
 					if (empty($this->userstores)) {
 						$this->getOtherUserStore();
 					}
@@ -924,8 +937,8 @@
 					}
 				}
 
-				// include public contact folders in addressbook if public folders are enabled, and Public contact folders is not disabled
-				if (!DISABLE_PUBLIC_CONTACT_FOLDERS && ENABLE_PUBLIC_FOLDERS) {
+				// Include public contact folders in addressbook if public folders and public contacts folders are enabled
+				if (ENABLE_PUBLIC_CONTACT_FOLDERS && ENABLE_PUBLIC_FOLDERS) {
 					$publicStore = $this->getPublicMessageStore();
 					if($publicStore !== false) {
 						$contactFolders = array_merge($contactFolders, $this->getContactFoldersForABContactProvider($publicStore));
@@ -970,7 +983,7 @@
 			// PR_IPM_SUBTREE_ENTRYID that can be used on your own and delegate stores.
 			if($storeProps[PR_MDB_PROVIDER] == ZARAFA_STORE_PUBLIC_GUID){
 				$subtreeEntryid = $storeProps[PR_IPM_PUBLIC_FOLDERS_ENTRYID];
-			}else{
+			} else {
 				$subtreeEntryid = $storeProps[PR_IPM_SUBTREE_ENTRYID];
 			}
 
