@@ -178,7 +178,7 @@ class WebAppAuthentication
 				WebAppAuthentication::_storeMAPISession(WebAppAuthentication::$_mapiSession->getSession());
 			} elseif ( WebAppAuthentication::$_errorCode == MAPI_E_LOGON_FAILED || WebAppAuthentication::$_errorCode == MAPI_E_UNCONFIGURED ) {
 				// Print error message to error_log of webserver
-				error_log('Kopano WebApp user: ' . $username . ': authentication failure at ' . getClientIPAddress());
+				error_log('Kopano WebApp user: ' . $username . ': authentication failure at MAPI. IP: ' . getClientIPAddress());
 			}
 		}
 
@@ -207,7 +207,7 @@ class WebAppAuthentication
 	/**
 	 * Restore a MAPISession from the serialized with kc_session_restore.
 	 *
-	 * @return boolean true if session has been restored succesfully
+	 * @return boolean true if session has been restored successfully
 	 */
 	private static function _restoreMAPISession() {
 		$encryptionStore = EncryptionStore::getInstance();
@@ -243,7 +243,7 @@ class WebAppAuthentication
 	 */
 	public static function isUsingSingleSignOn() {
 		// First check if the admin disabled using SSO on SSO systems
-		if ( DISABLE_REMOTE_USER_LOGIN ){
+		if (!ENABLE_REMOTE_USER_LOGIN){
 			return false;
 		}
 
@@ -344,10 +344,27 @@ class WebAppAuthentication
 		return WebAppAuthentication::getErrorCode();
 	}
 
+	/**
+	 * Function which try to open the default store using existing mapi session.
+	 * 
+	 * @return {Boolean} true if default store open else false.
+	 */
+	public static function isDefaultStoreAccessible(){
+		$mapiSession = WebAppAuthentication::getMapiSession();
+		$storeEntryID = $mapiSession->getDefaultMessageStoreEntryId();
+		try {
+			mapi_openmsgstore($mapiSession->getSession(), hex2bin($storeEntryID));
+		} catch (MAPIException $e) {
+			error_log('OIDC access token is expired therefore failed to open the default store with entryid ' . $storeEntryID);
+			return false;
+		}
+		return true;
+	} 
+
 	/**
 	 * Logs the user in with a given username and token in $_POST and logs
 	 * in with the special flag for token authentication enabled. If $new
-	 * is true it's assumed that a session does not exists and there wille
+	 * is true it's assumed that a session does not exists and there will
 	 * be a new one generated and fingerprint stored in session which is
 	 * later compared after logon. After successful logon the session is stored.
 	 *
