@@ -33,7 +33,7 @@ class FileLoader {
 			$jsLoadingSequence[] = "client/extjs-mod/extjs-mod.js";
 			$jsLoadingSequence[] = "client/tinymce/tinymce.min.js";
 			$jsLoadingSequence[] = "client/third-party/ux-thirdparty.js";
-			$jsLoadingSequence[] = "client/dompurify/purify.min.js";
+			$jsLoadingSequence[] = "client/dompurify/purify.js";
 		} else if ($load == LOAD_DEBUG) {
 			$jsLoadingSequence[] = "client/extjs/ext-base-debug.js";
 			$jsLoadingSequence[] = "client/extjs/ext-all-debug.js";
@@ -184,19 +184,19 @@ class FileLoader {
 		foreach($files as $file) {
 			$file = $base === true ? basename($file) : $file;
 			if($concatVersion) {
-				$file = $file."?version=".$this->getVersion();
+				$file = $file."?version=".$this->getCachebuster();
 			}
 			echo str_replace('{file}', $file, $template) . PHP_EOL;
 		}
 	}
 
 	/**
-	 * Return WebApp version.
-	 * @return String returns WebApp version
+	 * Return Cache busting version.
+	 * @return String returns WebApp version shasum'd for cache busting.
 	 */
-	public function getVersion()
+	public function getCachebuster()
 	{
-		return trim(file_get_contents('version'));
+		return trim(file_get_contents('cachebuster'));
 	}
 
 	/**
@@ -265,7 +265,7 @@ class FileLoader {
 				if(is_file($filepath) && $info == $ext){
 					$files[] = $filepath;
 				// Subdirectories will be scanned as well
-				}elseif($recursive && is_dir($filepath)){
+				} elseif($recursive && is_dir($filepath)){
 					$subDirFiles = array_merge($subDirFiles, $this->getListOfFiles($ext, $filepath, $recursive, $excludeFiles));
 				}
 			}
@@ -375,7 +375,7 @@ class FileLoader {
 						if($dependencyFilename != $filename){
 							$fileDependencies[ $filename ]['depends'][] = $dependencyFilename;
 						}
-					}else{
+					} else {
 						trigger_error('Unable to find @extends dependency "'.$fileData['extends'][$i].'" for file "'.$filename.'"');
 					}
 				}
@@ -390,7 +390,7 @@ class FileLoader {
 					if($dependencyFilename != $filename){
 						$fileDependencies[ $filename ]['depends'][] = $dependencyFilename;
 					}
-				}else{
+				} else {
 					trigger_error('Unable to find file #dependsFile dependency "'.$fileData['dependsFile'][$i].'" for file "'.$filename.'"');
 				}
 			}
@@ -442,7 +442,7 @@ class FileLoader {
 							if(!isset($fileDepths[ $dependencies[$i] ])){
 								$parentsDepthAssigned = false;
 								break;
-							}else{
+							} else {
 								// We should only take the highest depth
 								$highestParentDepth = max($highestParentDepth, $fileDepths[ $dependencies[$i] ]);
 							}
@@ -453,7 +453,7 @@ class FileLoader {
 							$changed = true;
 						}
 					// The node does not have any dependecies so its a root node.
-					}else{
+					} else {
 						$fileDepths[ $file ] = 0;
 						$changed = true;
 					}
@@ -478,7 +478,7 @@ class FileLoader {
 				if(!$dependencyData['core']){
 					$weight++;
 				}
-			}else{
+			} else {
 				// Make up a weight to put it at the end
 				$weight = count($fileData);
 			}
@@ -540,8 +540,8 @@ class FileLoader {
 		$jsTemplate = "\t\t<script type=\"text/javascript\" src=\"{file}\"></script>";
 		$this->printFiles($extjsFiles, $jsTemplate);
 		$this->printFiles($webappFiles, $jsTemplate);
-		$this->printFiles($pluginFiles, $jsTemplate);
-		$this->printFiles($remoteFiles, $jsTemplate);
+		$this->printFiles($pluginFiles, $jsTemplate, false, false);
+		$this->printFiles($remoteFiles, $jsTemplate, false, false);
 
 		if ($this->source) {
 			$contents = ob_get_contents();
@@ -582,10 +582,10 @@ class FileLoader {
 		$this->printFiles(array("client/resources/css/kopano.css"), $cssTemplate);
 
 		$pluginFiles = $this->getPluginCSSFiles(DEBUG_LOADER);
-		$this->printFiles($pluginFiles, $cssTemplate);
+		$this->printFiles($pluginFiles, $cssTemplate, false, false);
 
 		$remoteFiles = $this->getRemoteCSSFiles(DEBUG_LOADER);
-		$this->printFiles($remoteFiles, $cssTemplate);
+		$this->printFiles($remoteFiles, $cssTemplate, false, false);
 	}
 
 	/**
