@@ -66,6 +66,11 @@
 	define('tmrSent', 1);		// Task has been sent to multiple assignee
 	define('tmrReceived', 2);	// Task Request received has multiple assignee
 
+	//Task icon index.
+	define('ICON_TASK_ASSIGNEE', 0x00000502);
+	define('ICON_TASK_DECLINE', 0x00000506);
+	define('ICON_TASK_ASSIGNER', 0x00000503);
+
 	class TaskRequest {
 
 		// All recipient properties
@@ -234,7 +239,7 @@
 				$task = mapi_folder_createmessage($taskFolder);
 				
 				$sub = $this->getEmbeddedTask($this->message);
-				mapi_copyto($sub, array(), array(), $task);
+				mapi_copyto($sub, array(), array($this->props['categories']), $task);
 
 				$senderProps = array(
 					PR_SENT_REPRESENTING_NAME,
@@ -380,9 +385,21 @@
 					mapi_message_deleteattach($task, $taskAttach[PR_ATTACH_NUM]);
 				}
 
+				$ignoreProps = array(
+					$this->props['taskstate'],
+					$this->props['taskhistory'],
+					$this->props['taskmode'],
+					$this->props['taskfcreator']
+				);
+				// Ignore PR_ICON_INDEX when task request response
+				// is not received item.
+				if ($isReceivedItem === false) {
+					$ignoreProps[] = PR_ICON_INDEX;
+				}
+
 				// We copy all properties except taskstate, taskhistory, taskmode and taskfcreator properties
 				// from $sub message to $task even also we copy all attachments from $sub to $task message.
-				mapi_copyto($sub, array(), array($this->props['taskstate'], $this->props['taskhistory'], $this->props['taskmode'], $this->props['taskfcreator']), $task);
+				mapi_copyto($sub, array(), $ignoreProps , $task);
 				$senderProps = mapi_getprops($this->message, array(
 					PR_SENDER_NAME,
 					PR_SENDER_EMAIL_ADDRESS,
@@ -398,7 +415,7 @@
 
 				mapi_setprops($task, $senderProps);
 
-				// Update taskstate (what the task looks like) and task history (last action done by the assignee)
+				// Update taskstate and task history (last action done by the assignee)
 				mapi_setprops($task,$props);
 
 				mapi_savechanges($task);
@@ -476,7 +493,7 @@
 				$this->props['ownership'] => olDelegatedTask, /* Task has been assigned */
 				$this->props['taskhistory'] => thAssigned,	/* Task has been assigned */
 				PR_CONVERSATION_TOPIC => $messageprops[PR_SUBJECT],
-				PR_ICON_INDEX => 1283						/* Task request icon*/
+				PR_ICON_INDEX => ICON_TASK_ASSIGNER
 			));
 			$this->setLastUser();
 			$this->setOwnerForAssignor();
@@ -485,8 +502,9 @@
 			// Create outgoing task request message
 			$outgoing = $this->createOutgoingMessage();
 
-			// No need to copy PR_SENT_* information in to outgoing message.
-			$ignoreProps = array(PR_SENT_REPRESENTING_NAME, PR_SENT_REPRESENTING_EMAIL_ADDRESS, PR_SENT_REPRESENTING_ADDRTYPE, PR_SENT_REPRESENTING_ENTRYID, PR_SENT_REPRESENTING_SEARCH_KEY);
+
+			// No need to copy PR_ICON_INDEX and  PR_SENT_* information in to outgoing message.
+				$ignoreProps = array(PR_ICON_INDEX, PR_SENT_REPRESENTING_NAME, PR_SENT_REPRESENTING_EMAIL_ADDRESS, PR_SENT_REPRESENTING_ADDRTYPE, PR_SENT_REPRESENTING_ENTRYID, PR_SENT_REPRESENTING_SEARCH_KEY);
 			mapi_copyto($this->message, array(), $ignoreProps, $outgoing);
 
 			// Make it a task request, and put it in sent items after it is sent
@@ -496,8 +514,7 @@
 				$this->props['taskmode'] => tdmtTaskReq,	/* for the recipient it's a request */
 				$this->props['updatecount'] => 1,			/* version 2 is in the attachment */
 				PR_SUBJECT_PREFIX => $prefix,
-				PR_SUBJECT => $prefix . $messageprops[PR_SUBJECT],
-				PR_ICON_INDEX => 0xFFFFFFFF,				/* show assigned icon */
+				PR_SUBJECT => $prefix . $messageprops[PR_SUBJECT]
 			));
 
 			$attach = mapi_message_createattach($outgoing);
@@ -581,7 +598,7 @@
 				$taskProps[$this->props["taskfcreator"]] = false;
 				$taskProps[$this->props["ownership"]] = $isReceivedItem ? olOwnTask : olDelegatedTask;
 				$taskProps[$this->props["task_acceptance_state"]] = olTaskNotDelegated;
-				$taskProps[PR_ICON_INDEX] = 1282;
+				$taskProps[PR_ICON_INDEX] = ICON_TASK_ASSIGNEE;
 
 				mapi_setprops($task, $taskProps);
 				$this->setAssignorInRecipients($task);
@@ -833,7 +850,7 @@
 
 			$message = !$this->isTaskRequest() ? $this->message : $this->getAssociatedTask(false);
 
-			$ignoreProps = array(PR_SENT_REPRESENTING_NAME, PR_SENT_REPRESENTING_EMAIL_ADDRESS, PR_SENT_REPRESENTING_ADDRTYPE, PR_SENT_REPRESENTING_ENTRYID, PR_SENT_REPRESENTING_SEARCH_KEY);
+			$ignoreProps = array(PR_ICON_INDEX, $this->props["categories"], PR_SENT_REPRESENTING_NAME, PR_SENT_REPRESENTING_EMAIL_ADDRESS, PR_SENT_REPRESENTING_ADDRTYPE, PR_SENT_REPRESENTING_ENTRYID, PR_SENT_REPRESENTING_SEARCH_KEY);
 
 			mapi_copyto($message, array(), $ignoreProps, $outgoing);
 			mapi_copyto($message, array(), array(), $sub);
@@ -846,11 +863,14 @@
 			switch($type) {
 				case tdmtTaskAcc:
 					$props[PR_MESSAGE_CLASS] = "IPM.TaskRequest.Accept";
+					mapi_setprops($sub,array(PR_ICON_INDEX => ICON_TASK_ASSIGNER));
 					break;
 				case tdmtTaskDec:
 					$props[PR_MESSAGE_CLASS] = "IPM.TaskRequest.Decline";
+					mapi_setprops($sub,array(PR_ICON_INDEX => ICON_TASK_DECLINE));
 					break;
 				case tdmtTaskUpd:
+					mapi_setprops($sub,array(PR_ICON_INDEX => ICON_TASK_ASSIGNER));
 					if($messageprops[$this->props['complete']]) {
 						$props[PR_MESSAGE_CLASS] = "IPM.TaskRequest.Complete";
 					} else {
@@ -866,7 +886,6 @@
 			$props[PR_SUBJECT] = $prefix . $messageprops[PR_CONVERSATION_TOPIC];
 			$props[$this->props['taskmode']] = $type;
 			$props[$this->props['task_assigned_time']] = time();
-			$props[PR_ICON_INDEX] = 0xFFFFFFFF;
 
 			mapi_setprops($outgoing, $props);
 
@@ -1022,17 +1041,19 @@
 			}
 
 			$recips = array();
-			$taskReqProps = mapi_getprops($this->message, array(PR_SENT_REPRESENTING_NAME, PR_SENT_REPRESENTING_EMAIL_ADDRESS, PR_SENT_REPRESENTING_ENTRYID, PR_SENT_REPRESENTING_ADDRTYPE));
+			$taskReqProps = mapi_getprops($this->message, array(PR_SENT_REPRESENTING_NAME, PR_SENT_REPRESENTING_EMAIL_ADDRESS, PR_SENT_REPRESENTING_ENTRYID, PR_SENT_REPRESENTING_ADDRTYPE, PR_SENT_REPRESENTING_SEARCH_KEY));
 			$associatedTaskProps = mapi_getprops($task, array($this->props['taskupdates'], $this->props['tasksoc'], $this->props['taskmultrecips']));
 
 			// Build assignor info
-			$assignor = array(	PR_ENTRYID => $taskReqProps[PR_SENT_REPRESENTING_ENTRYID],
-								PR_DISPLAY_NAME => $taskReqProps[PR_SENT_REPRESENTING_NAME],
-								PR_EMAIL_ADDRESS => $taskReqProps[PR_SENT_REPRESENTING_EMAIL_ADDRESS],
-								PR_RECIPIENT_DISPLAY_NAME => $taskReqProps[PR_SENT_REPRESENTING_NAME],
-								PR_ADDRTYPE => empty($taskReqProps[PR_SENT_REPRESENTING_ADDRTYPE]) ? 'SMTP' : $taskReqProps[PR_SENT_REPRESENTING_ADDRTYPE],
-								PR_RECIPIENT_FLAGS => recipSendable
-						);
+			$assignor = array(
+				PR_ENTRYID => $taskReqProps[PR_SENT_REPRESENTING_ENTRYID],
+				PR_DISPLAY_NAME => $taskReqProps[PR_SENT_REPRESENTING_NAME],
+				PR_EMAIL_ADDRESS => $taskReqProps[PR_SENT_REPRESENTING_EMAIL_ADDRESS],
+				PR_RECIPIENT_DISPLAY_NAME => $taskReqProps[PR_SENT_REPRESENTING_NAME],
+				PR_ADDRTYPE => empty($taskReqProps[PR_SENT_REPRESENTING_ADDRTYPE]) ? 'SMTP' : $taskReqProps[PR_SENT_REPRESENTING_ADDRTYPE],
+				PR_RECIPIENT_FLAGS => recipSendable,
+				PR_SEARCH_KEY => $taskReqProps[PR_SENT_REPRESENTING_SEARCH_KEY]
+			);
 
 			// Assignor has requested task updates, so set him/her as MAPI_CC in recipienttable.
 			if ((isset($associatedTaskProps[$this->props['taskupdates']]) && $associatedTaskProps[$this->props['taskupdates']])
@@ -1060,6 +1081,10 @@
 		function deleteReceivedTR()
 		{
 			$store = $this->getTaskFolderStore();
+			$storeType = mapi_getprops($store, array(PR_MDB_PROVIDER));
+			if ($storeType[PR_MDB_PROVIDER] === ZARAFA_STORE_PUBLIC_GUID) {
+				$store = $this->getDefaultStore();
+			}
 			$inbox = mapi_msgstore_getreceivefolder($store);
 
 			$storeProps = mapi_getprops($store, array(PR_IPM_WASTEBASKET_ENTRYID));
@@ -1094,7 +1119,7 @@
 		 *
 		 * If it is a task update, then only recipient type MAPI_CC are taken from the task message.
 		 *
-		 * If it is accept/decline response, then PR_SENT_REPRESENTATING_XXXX are taken as recipient.
+		 * If it is accept/decline response, then PR_SENT_REPRESENTATION_XXXX are taken as recipient.
 		 *
 		 *@param $outgoing MAPI_message outgoing mapi message 
 		 *@param $responseType String response type
