@@ -73,8 +73,8 @@
 								$this->handleUnknownActionType($actionType);
 						}
 					} catch (MAPIException $e) {
-						if (isset($action['ignoreException']) && $action['ignoreException'] === true) {
-							$e->setNotifiactionType('console');
+						if (isset($action['suppress_exception']) && $action['suppress_exception'] === true) {
+							$e->setNotificationType('console');
 						}
 						$this->processException($e, $actionType);
 					}
@@ -122,7 +122,7 @@
 							// and user B 'categories' => -2062610402,
 							$GLOBALS["properties"]->setActiveStore($store[$index]);
 							$this->properties = $GLOBALS["properties"]->getAppointmentListProperties();
-							
+
 							$data["item"] = array_merge($data["item"], $this->getCalendarItems($store[$index], $entryid[$index], $this->startdate, $this->enddate));
 						}
 					} else {
@@ -155,7 +155,7 @@
 			$restriction =
 				// OR
 				//  - Either we want all appointments which fall within the given range
-				//	- Or we want all recurring items which we manually check if an occurence
+				//	- Or we want all recurring items which we manually check if an occurrence
 				//	  exists which will fall inside the range
 				Array(RES_OR,
 					Array(
@@ -257,7 +257,7 @@
 					{
 						$item = Conversion::mapMAPI2XML($this->properties, $recuritem);
 
-						// Single occurences are never recurring
+						// Single occurrences are never recurring
 						$item['props']['recurring'] = false;
 
 						if(isset($recuritem["exception"])) {
@@ -337,6 +337,8 @@
 					$item['props']['reminder'] = 0;
 					$item['props']['access'] = 0;
 					$item['props']['sent_representing_name'] = '';
+					$item['props']['display_to'] = '';
+					$item['props']['display_cc'] = '';
 					$item['props']['sender_name'] = '';
 
 					return $item;
