@@ -282,12 +282,13 @@
 		 */
 		function setConversationIndex($action, &$props)
 		{
-			$serverVersion = phpversion('mapi');
-
 			// Older version of the core does not support 
 			// mapi_createconversationindex function.
-			if(version_compare($serverVersion, '10.0.0') === -1) {
-				error_log(sprintf("Core '%s' version does not support mapi_createconversationindex function", $serverVersion));
+			if(function_exists("mapi_createconversationindex") === false) {
+				// Log a message that KC does not support conversationindex function.
+				// Commented for now, since it spams admin as this version of core is not released yet. 
+				// We can enable it later if needed.
+				error_log(sprintf("Core '%s' version does not support mapi_createconversationindex function", phpversion('mapi')));
 				return;
 			}
 	
