@@ -1,5 +1,6 @@
 <?php
-	/**
+
+/**
 	 * Hierarchy Module
 	 *
 	 * @todo
@@ -32,7 +33,7 @@
 			$GLOBALS["bus"]->registerNotifier('hierarchynotifier', REQUEST_ENTRYID);
 			$GLOBALS["bus"]->registerNotifier('newmailnotifier', REQUEST_ENTRYID);
 		}
-		
+
 		/**
 		 * Function which returns a list of entryids, which is used to register this module. It
 		 * returns the ipm_subtree entryids of every message store.
@@ -46,10 +47,10 @@
 			foreach ($storelist as $entryid => $store) {
 				$entryids[] = bin2hex($entryid);
 			}
-			
+
 			return $entryids;
 		}
-		
+
 		/**
 		 * Executes all the actions in the $data variable.
 		 * @return boolean true on success or false on fialure.
@@ -243,7 +244,7 @@
 													sleep(1);
 													$this->createLinkedSearchFolder($newSearchFolder);
 												}
-											}else {
+											} else {
 												$this->addFolder($store, $parententryid, $action["props"]["display_name"], $action["props"]["container_class"]);
 											}
 										if($action["props"]["container_class"] === "IPF.Contact"){
@@ -252,7 +253,7 @@
 									}
 								}
 								break;
-							
+
 							case "closesharedfolder":
 								if (isset($action["folder_type"]) && $action["folder_type"] != "all") {
 									// We're closing a Shared folder, check if we still have other
@@ -268,7 +269,10 @@
 								} else {
 									// We're closing a Shared Store, simply remove it from the session.
 									$entryid = $GLOBALS["mapisession"]->removeUserStore($action["user_name"]);
-									$this->removeFromFavorite(hex2bin($action["store_entryid"]), $store, PR_WLINK_STORE_ENTRYID, false);
+
+									if (isset($action["remove_favorites"]) && $action["remove_favorites"]) {
+										$this->removeFromFavorite(hex2bin($action["store_entryid"]), $store, PR_WLINK_STORE_ENTRYID, false);
+									}
 								}
 
 								$data = array();
@@ -281,7 +285,7 @@
 								$GLOBALS["bus"]->addData($this->getResponseData());
 								$GLOBALS["bus"]->notify(ADDRESSBOOK_ENTRYID,OBJECT_SAVE);
 								break;
-							
+
 							case "opensharedfolder":
 								$username = strtolower($action["user_name"]);
 								$store = $GLOBALS["mapisession"]->addUserStore($username);
@@ -331,6 +335,9 @@
 
 								$this->sendFeedback(true);
 								break;
+							case "ensure":
+								$this->ensureLicense($action);
+								break;
 							default:
 								$this->handleUnknownActionType($actionType);
 						}
@@ -345,7 +352,7 @@
 		 * Function does customization of exception based on module data.
 		 * like, here it will generate display message based on actionType
 		 * for particular exception, and send feedback to the client.
-		 * 
+		 *
 		 * @param object $e Exception object
 		 * @param string $actionType the action type, sent by the client
 		 * @param MAPIobject $store Store object of the folder.
@@ -472,7 +479,7 @@
 
 			parent::handleException($e, $actionType, $store, $parententryid, $entryid, $action);
 		}
-		
+
 		/**
 		 * Generates the hierarchy list. All folders and subfolders are added to response data.
 		 */
@@ -498,7 +505,7 @@
 			$data = $GLOBALS["operations"]->setFolder($folderProps);
 			$this->addActionData($actionType, $data);
 		}
-		
+
 		/**
 		 * Adds a folder to the hierarchylist.
 		 * @param object $store Message Store Object.
@@ -523,10 +530,10 @@
 				$props[PR_ENTRYID] = $parententryid;
 				$GLOBALS["bus"]->notify(bin2hex($parententryid), OBJECT_SAVE, $props);
 			}
-			
+
 			return $result;
 		}
-		
+
 		/**
 		* returns properties of a folder, used by the properties dialog
 		*/
@@ -558,7 +565,7 @@
 			if (!isset($data["props"]["message_size"])){
 				$data["props"]["message_size"] = round($GLOBALS["operations"]->calcFolderMessageSize($folder, false));
 			}
-			
+
 			// retrieving folder permissions
 			$data["permissions"] = array(
 				"item" => $this->getFolderPermissions($folder)
@@ -644,7 +651,7 @@
 			if (isset($action["permissions"])){
 				$this->setFolderPermissions($folder, $action["permissions"]);
 			}
-			
+
 			mapi_savechanges($folder);
 		}
 
@@ -656,7 +663,7 @@
 
 			$store = $GLOBALS["mapisession"]->openMessageStore($folderProps[PR_STORE_ENTRYID]);
 			if ($folderProps[PR_DISPLAY_NAME] == "IPM_SUBTREE"){
-				$folder = $store; 
+				$folder = $store;
 			}
 
 			$grants = mapi_zarafa_getpermissionrules($folder, ACCESS_TYPE_GRANT);
@@ -677,7 +684,7 @@
 			}
 
 			$result = $grants;
-			return $result;			
+			return $result;
 		}
 
 		function setFolderPermissions($folder, $permissions)
@@ -700,7 +707,7 @@
 				$folder = $store;
 			}
 
-			// first, get the current permissions because we need to delete all current acl's 
+			// first, get the current permissions because we need to delete all current acl's
 			$curAcls = mapi_zarafa_getpermissionrules($folder, ACCESS_TYPE_GRANT);
 
 			// First check which permissions should be removed from the existing list
@@ -744,7 +751,7 @@
 					);
 				}
 				unset($addAcl);
-			}			
+			}
 
 			if (!empty($curAcls)) {
 				mapi_zarafa_setpermissionrules($folder, $curAcls);
@@ -1018,7 +1025,7 @@
 				$GLOBALS["bus"]->notify(bin2hex($props[PR_ENTRYID]), OBJECT_SAVE, $props);
 			}
 		}
-		
+
 		/**
 		 * Deletes a folder in the hierarchylist.
 		 * @param object $store Message Store Object.
@@ -1075,7 +1082,7 @@
 				}
 			}
 		}
-		
+
 		/**
 		 * Deletes all messages in a folder.
 		 * @param object $store Message Store Object.
@@ -1123,7 +1130,7 @@
 				$GLOBALS["bus"]->addData($this->getResponseData());
 			}
 		}
-		
+
 		/**
 		 * Copies of moves a folder in the hierarchylist.
 		 * @param object $store Message Store Object.
@@ -1176,7 +1183,7 @@
 				// Update subfolders of copy/move folder
 				$folder = mapi_msgstore_openentry($deststore, $destfolderentryid);
 				$hierarchyTable = mapi_folder_gethierarchytable($folder, CONVENIENT_DEPTH | MAPI_DEFERRED_ERRORS);
-				mapi_table_sort($hierarchyTable, array(PR_DISPLAY_NAME => TABLE_SORT_ASCEND), TBL_BATCH);
+				mapi_table_sort($hierarchyTable, array(PR_CREATION_TIME => TABLE_SORT_ASCEND), TBL_BATCH);
 
 				/**
 				 * remove hidden folders, folders with PR_ATTR_HIDDEN property set
@@ -1207,7 +1214,7 @@
 
 				if (is_array($subfolders)) {
 					foreach($subfolders as $subfolder) {
-						$folderObject = mapi_msgstore_openentry($deststore, $subfolder[PR_ENTRYID]); 
+						$folderObject = mapi_msgstore_openentry($deststore, $subfolder[PR_ENTRYID]);
 						$folderProps = mapi_getprops($folderObject, array(PR_ENTRYID, PR_STORE_ENTRYID));
 						$GLOBALS["bus"]->notify(bin2hex($subfolder[PR_ENTRYID]), OBJECT_SAVE, $folderProps);
 					}
@@ -1225,7 +1232,7 @@
 				}
 			}
 		}
-		
+
 		/**
 		 * Set all messages read.
 		 * @param object $store Message Store Object.
@@ -1254,5 +1261,68 @@
 				$GLOBALS["bus"]->addData($this->getResponseData());
 			}
 		}
+
+		/**
+		 * Function used to ensure the license claims for supported(kopano one) webapp.
+		 * @param array $action The action data sent by the client.
+		 */
+		function ensureLicense($action)
+		{
+			$stateData = EnsureLicense::retrieveCache();
+			$allowUpdate = $this->isRequiredUpdate($stateData, $action);
+			$data = array();
+
+			// No need to update the cache just reuse the
+			// 'status' from cached data.
+			if ($allowUpdate === false) {
+				$data["status"] = $stateData["status"];
+
+				$this->addActionData("ensure", $data);
+				$GLOBALS["bus"]->addData($this->getResponseData());
+				return;
+			}
+
+			try {
+				$ok = EnsureLicense::ensureOK("groupware");
+				$data["status"] = $ok !== false ? $ok["err"] : 0;
+			} catch (KUSTOMER\NumericException $e) {
+				error_log($e->getMessage());
+				$data["status"] = $e->getCode();
+			}
+
+			$data["hasPayPerUse"] = is_null(EnsureLicense::$isPayPerUse) ? false : EnsureLicense::$isPayPerUse;
+			EnsureLicense::updateCache(array(
+				"last_ensured_time"=>time(),
+				"status"=> $data["status"],
+				"hasPayPerUse" => $data["hasPayPerUse"],
+			));
+
+			$this->addActionData("ensure", $data);
+			$GLOBALS["bus"]->addData($this->getResponseData());
+		}
+
+		/**
+		 * Function used to check ensure license cache data
+		 * needs to update or not.
+		 *
+		 * @param array $stateData The cached data of ensured license.
+		 * @param array $action The action data sent by the client.
+		 * @return bool true to update the cache else false.
+		 */
+		function isRequiredUpdate($stateData, $action)
+		{
+			if ($stateData === false || $action["init"] === true) {
+				return true;
+			}
+
+			if (isset($stateData["last_ensured_time"])) {
+				$interval = time() - $stateData["last_ensured_time"];
+				// If interval is more then 10 minuet then update the
+				// ensure license cache.
+				return $interval >= 10 * 60;
+			}
+
+			return true;
+		}
 	}
 ?>
