@@ -268,7 +268,7 @@
                                         break;
 
 									default:
-										// Deleting an occurence means that we have to save the message to
+										// Deleting an occurrence means that we have to save the message to
 										// generate an exception. So when the basedate is provided, we actually
 										// perform a save rather then delete.
 										if (isset($action['basedate']) && !empty($action['basedate'])) {
@@ -312,8 +312,13 @@
 							$e->setDisplayMessage(_("You have insufficient privileges to open this message."));
 						} elseif($e->getCode() == MAPI_E_NOT_FOUND) {
 							$e->setDisplayMessage(_("Could not find message, either it has been moved or deleted or you don't have access to open this message."));
+							// Show error in console instead of a pop-up
+							if (isset($action["message_action"]['suppress_exception']) && $action["message_action"]['suppress_exception'] === true) {
+								$e->setNotificationType('console');
+							}
 						} else {
 							$e->setDisplayMessage(_("Could not open message."));
+							$e->allowToShowDetailsMessage = true;
 						}
 						break;
 
@@ -456,7 +461,6 @@
 			} else {
 				// get message props of the message
 				$data['item'] = $GLOBALS['operations']->getMessageProps($store, $message, $this->properties, $this->plaintext);
-
 				$messageClass = !empty($data['item']['props']['message_class']) ? $data['item']['props']['message_class'] : '';
 
 				// Check for meeting request, do processing if necessary
@@ -530,6 +534,18 @@
 					$data['item']['props']['body'] = $this->getNDRbody($message);
 				}
 			}
+			
+			$userEntryId = '';
+			if (isset($data['item']['props']['sent_representing_entryid'])) {
+				$userEntryId = hex2bin($data['item']['props']['sent_representing_entryid']);
+			} else if (isset($data['item']['props']['sender_entryid'])) {
+				$userEntryId = hex2bin($data['item']['props']['sender_entryid']);
+			}
+			
+			// get user image saved in LDAP.
+			if (!empty($userEntryId)) {
+				$data['item']['props']['user_image'] = $GLOBALS['operations']->getCompressedUserImage($userEntryId);
+			}
 
 			// Allowing to hook in just before the data sent away to be sent to the client
 			$GLOBALS['PluginManager']->triggerHook('server.module.itemmodule.open.after', array(
@@ -694,14 +710,6 @@
 					$moveMessages = true;
 				}
 
-				// drag & drop from a public store to other store should always be copy instead of move
-				$destStoreProps = mapi_getprops($dest_store, array(PR_MDB_PROVIDER));
-				$storeProps = mapi_getprops($store, array(PR_MDB_PROVIDER));
-
-				if($storeProps[PR_MDB_PROVIDER] == ZARAFA_STORE_PUBLIC_GUID && $destStoreProps[PR_MDB_PROVIDER] != ZARAFA_STORE_PUBLIC_GUID) {
-					$moveMessages = false;
-				}
-
 				// if item has some set of props that need to be saved into the newly copied/moved item
 				$copyProps = array();
 				if (isset($action["message_action"]["dropmodifications"])) {
@@ -709,7 +717,7 @@
 				}
 
 				// if item has some changes made before choosing different calendar from create-in dropdown
-				if (isset($action["props"])) {
+				if (isset($action["props"]) && !empty($action["props"])) {
 					$copyProps = Conversion::mapXML2MAPI($this->properties, $action["props"]);
 				}
 
@@ -720,7 +728,17 @@
 				$storeprops = mapi_getprops($store, array(PR_ENTRYID));
 				$props[PR_STORE_ENTRYID] = $storeprops[PR_ENTRYID];
 
-				$result = $GLOBALS["operations"]->copyMessages($store, $parententryid, $dest_store, $dest_folderentryid, $entryids, $moveMessages ? array() : $this->skipCopyProperties, $moveMessages, $copyProps);
+				$skipCopyProperties = array();
+				if (isset($action["message_action"]["unset_Private"])) {
+					if ($moveMessages) {
+						array_push($skipCopyProperties, $this->properties["private"], $this->properties["sensitivity"]);
+					} else {
+						array_push($this->skipCopyProperties, $this->properties["private"], $this->properties["sensitivity"]);
+					}
+				}
+					
+									
+				$result = $GLOBALS["operations"]->copyMessages($store, $parententryid, $dest_store, $dest_folderentryid, $entryids, $moveMessages ? $skipCopyProperties : $this->skipCopyProperties, $moveMessages, $copyProps);
 
 				if($result) {
 					if($moveMessages) {
