@@ -42,12 +42,11 @@
 
 		/**
 		 * Checks if the list should be returned as conversations or as a plain list.
-		 *
 		 * @return Boolean True if the list should be returned as conversations, false otherwise
 		 */
 		function useConversationView() {
+		// We also check if live scroll is enabled. Ref KW-3391.
 			return
-				ENABLE_CONVERSATION_VIEW === true &&
 				$GLOBALS['settings']->get('zarafa/v1/contexts/mail/enable_conversation_view') === true &&
 				$GLOBALS['settings']->get('zarafa/v1/contexts/mail/enable_live_scroll') !== false;
 		}
@@ -212,9 +211,70 @@
 				return parent::messageList($store, $entryid, $action, $actionType);
 			}
 
+			if (isset($action['restriction']['filter']) && $action['restriction']['filter'] !== false) {
+				return $this->prepareFilteredData($store, $action, $actionType);
+			}
+
 			return $this->conversationList($store, $entryid, $action, $actionType);
 		}
 
+		/**
+		 * Function will prepare filtered data in the list form by applying restriction on search folder
+		 * of the conversation data.
+		 * @param object $store MAPI Message Store Object
+		 * @param array $action the action data, sent by the client
+		 * @param string $actionType the action type, sent by the client
+		 * @return boolean true on success or false on failure
+		 */
+		function prepareFilteredData($store, $action, $actionType) 
+		{
+			$searchFolder = $this->getConversationSearchFolder($this->currentActionData['store']);
+			if (!$searchFolder) {
+				// TODO: Improve error logging
+				error_log('no search folder found');
+				return [];
+			}
+			
+			$entryid = mapi_getprops($searchFolder, array(PR_ENTRYID))[PR_ENTRYID];
+			$this->parseRestriction($action);
+
+			// Sort
+			$this->parseSortOrder($action, null, true);
+
+			$limit = false;
+			if(isset($action['restriction']['limit'])){
+				$limit = $action['restriction']['limit'];
+			} else {
+				$limit = $GLOBALS['settings']->get('zarafa/v1/main/page_size', 50);
+			}
+
+			// Get the table and merge the arrays
+			$data = $GLOBALS["operations"]->getTable($store, $entryid, $this->properties, $this->sort, $this->start, $limit, $this->restriction);
+
+			$data = $this->filterPrivateItems($data);
+			
+			// Allowing to hook in just before the data sent away to be sent to the client
+			$GLOBALS['PluginManager']->triggerHook('server.module.listmodule.list.after', array(
+				'moduleObject' =>& $this,
+				'store' => $store,
+				'entryid' => $entryid,
+				'action' => $action,
+				'data' =>& $data,
+			));
+
+			foreach ($data["item"] as $key => $itemData) {
+				$itemData['props']['folder_name'] = $GLOBALS['entryid']->compareEntryIds($itemData['parent_entryid'], $this->_inboxEntryId) ? 'inbox' : 'sent_items';
+				$data["item"][$key] = $itemData;
+			}
+
+			// unset will remove the value but will not regenerate array keys, so we need to
+			// do it here
+			$data["item"] = array_values($data["item"]);
+
+			$this->addActionData($actionType, $data);
+			$GLOBALS["bus"]->addData($this->getResponseData());
+		}
+
 		/**
 		 * Function which retrieves a list of messages as conversations in a folder
 		 * @param object $store MAPI Message Store Object
@@ -261,13 +321,6 @@
 				$folderData["content_unread"] = $this->getInboxTotalUnread();
 			}
 
-			$searchFolder = $this->getConversationSearchFolder($store);
-			$totalRowCount = 0;
-			if ($searchFolder) {
-				$table = mapi_folder_getcontentstable($searchFolder, MAPI_DEFERRED_ERRORS);
-				$totalRowCount = mapi_table_getrowcount($table);
-			}
-
 			// Get the number of 'real' records that is sent back (i.e. without the conversation header records)
 			$itemCount = 0;
 			foreach ($items as $item) {
@@ -303,7 +356,7 @@
 		}
 
 		/**
-		 * Will iterate to retreive the requested number of conversations (or whatever is left)
+		 * Will iterate to retrieve the requested number of conversations (or whatever is left)
 		 *
 		 * @param Integer $count Number of conversations to fetch
 		 * @return Array Array of item objects grouped by conversation (together with headers)
@@ -744,7 +797,12 @@
 			$searchRoot = $this->getSearchFoldersRoot($store);
 
 			try {
-				// Try to create a new search folder for the conversations. If it fails, we'll assume it already exists.
+				// Return the search folder if it exist.
+				if ($this->doesSearchFolderExist($searchRoot)) {
+					return mapi_folder_createfolder($searchRoot, 'Conversation view search (WebApp)', NULL, OPEN_IF_EXISTS, FOLDER_SEARCH);
+				}
+
+				// Try to create a new search folder for the conversations if it doesn't exist.
 				$searchFolder = mapi_folder_createfolder($searchRoot, 'Conversation view search (WebApp)', NULL, NULL, FOLDER_SEARCH);
 
 				// Find the entryids of the folders we want to search in
@@ -801,26 +859,55 @@
 
 				// TODO: Let the client know if the search has not finished, so it can choose to continue
 			} catch (MAPIException $e) {
-				// Folder already exists. Let's open it
-				try {
-					$searchFolder = mapi_folder_createfolder($searchRoot, 'Conversation view search (WebApp)', NULL, OPEN_IF_EXISTS, FOLDER_SEARCH);
-				} catch (MAPIException $e) {
-					// TODO: Improve error logging
-					error_log('Error creating search folder for conversation view: ' . $e->getMessage());
-
-					// don't propagate the event to higher level exception handlers
-					$e->setHandled();
-
-					return false;
-				}
+				// TODO: Improve error logging
+				error_log('Error creating search folder for conversation view: ' . $e->getMessage());
 
 				// don't propagate the event to higher level exception handlers
 				$e->setHandled();
+
+				return false;
 			}
 
 			return $searchFolder;
 		}
 
+		/**
+		 * Helper function which determines whether the conversation search folder already exist.
+		 *
+		 * @param Resource $searchRoot FINDER_ROOT folder of the store in which we need to find conversation search folder.
+		 * @return Boolean true if conversation search folder already exist else false.
+		 */
+		function doesSearchFolderExist($searchRoot) {
+			$searchRootFolderTable = mapi_folder_gethierarchytable($searchRoot);
+			$restriction = array(
+				RES_AND,
+				array(
+					array(
+						RES_PROPERTY,
+						array(
+							RELOP => RELOP_EQ,
+							ULPROPTAG => PR_FOLDER_TYPE,
+							VALUE => array(PR_FOLDER_TYPE => FOLDER_SEARCH)
+						)
+					),
+					array(
+						RES_CONTENT,
+						array(
+							ULPROPTAG => PR_DISPLAY_NAME,
+							FUZZYLEVEL => FL_FULLSTRING,
+							VALUE => array(PR_DISPLAY_NAME => 'Conversation view search (WebApp)')
+						)
+					)
+				)
+			);
+
+			mapi_table_restrict($searchRootFolderTable, $restriction);
+			$folders = mapi_table_queryallrows($searchRootFolderTable, array(PR_DISPLAY_NAME));
+				
+			// If we get the data that means we already have the search folder.
+			return !empty($folders);
+		}
+
 		/**
 		 * Function does customization of exception based on module data.
 		 * like, here it will generate display message based on actionType
