@@ -4,7 +4,8 @@ include(BASE_PATH . 'server/includes/templates/serverinfo.php');
 
 $loader = new FileLoader();
 
-$versionInfo['webapp'] = $loader->getVersion();
+$versionInfo['webapp'] = getWebappVersion();
+$versionInfo['cachebuster'] = $loader->getCachebuster();
 $serverConfig = array(
 	'enable_plugins'				=> ENABLE_PLUGINS ? true : false,
 	'enable_advanced_settings'		=> ENABLE_ADVANCED_SETTINGS ? true : false,
@@ -16,13 +17,16 @@ $serverConfig = array(
 	'active_theme'					=> Theming::getActiveTheme(),
 	'iconsets'						=> Iconsets::getIconsets(),
 	'active_iconset'				=> Iconsets::getActiveIconset(),
+	'enable_themes'					=> ENABLE_THEMES,
+	'enable_iconsets'               => ENABLE_ICONSETS,
+	'enable_widgets'				=> ENABLE_WIDGETS
 );
 ?>
 <!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
 <html>
 
 	<head>
-		<meta name="Generator" content="Kopano WebApp v<?php echo $loader->getVersion()?>">
+		<meta name="Generator" content="Kopano WebApp v-<?php echo getWebappVersion()?>">
 		<meta http-equiv="Content-Type" content="text/html; charset=utf-8">
 		<meta http-equiv="X-UA-Compatible" content="IE=edge" />
 		<title><?php echo $webappTitle; ?></title>
@@ -36,6 +40,11 @@ $serverConfig = array(
 		<?php
 			$loader->cssOrder();
 			echo Theming::getStyles($theme);
+
+			// Load OIDC JavaScript for refreshing of the token.
+			if (OIDC_ISS !== "") {
+				require_once(BASE_PATH . 'client/oidc.js.php');
+			}
 		?>
 	</head>
 
@@ -56,7 +65,7 @@ $serverConfig = array(
 		<script type="text/javascript"><?php require(BASE_PATH . 'client/resize.js'); ?></script>
 
 		<!-- Translations -->
-		<script type="text/javascript" src="index.php?version=<?php echo $loader->getVersion() ?>&load=translations.js&lang=<?php echo $Language->getSelected()?>"></script>
+		<script type="text/javascript" src="index.php?version=<?php echo getWebappVersion() ?>&load=translations.js&lang=<?php echo $Language->getSelected()?>"></script>
 		<!-- JS Files -->
 		<?php $loader->jsOrder(); ?>
 
